==> haskell-stringbuilder-0.5.1-592-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-stringbuilder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stringbuilder
version:              0.5.1
visibility:           public
id:                   stringbuilder-0.5.1-7KEYQoGuVF39TfdtdpaL4f
key:                  stringbuilder-0.5.1-7KEYQoGuVF39TfdtdpaL4f
license:              MIT
copyright:            (c) 2011-2018 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
synopsis:             A writer monad for multi-line string literals
description:          <https://github.com/sol/stringbuilder#readme>
category:             Testing
abi:                  f23a854589006865a8f54cc3d00deebd
exposed:              True
exposed-modules:      Data.String.Builder
import-dirs:          /usr/lib/ghc-9.6.6/site-local/stringbuilder-0.5.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/stringbuilder-0.5.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/stringbuilder-0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-stringbuilder
hs-libraries:         HSstringbuilder-0.5.1-7KEYQoGuVF39TfdtdpaL4f
depends:              base-4.18.2.1
haddock-interfaces:
    /usr/share/doc/haskell-stringbuilder/html/stringbuilder.haddock

haddock-html:         /usr/share/doc/haskell-stringbuilder/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-stringbuilder-0.5.1-594-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-stringbuilder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stringbuilder
version:              0.5.1
visibility:           public
id:                   stringbuilder-0.5.1-9uHek5neZV4GQIWVfQI3Ym
key:                  stringbuilder-0.5.1-9uHek5neZV4GQIWVfQI3Ym
license:              MIT
copyright:            (c) 2011-2018 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
synopsis:             A writer monad for multi-line string literals
description:          <https://github.com/sol/stringbuilder#readme>
category:             Testing
abi:                  8811ab6ec5c17de53021c22435e962ba
exposed:              True
exposed-modules:      Data.String.Builder
import-dirs:          /usr/lib/ghc-9.6.6/site-local/stringbuilder-0.5.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/stringbuilder-0.5.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/stringbuilder-0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-stringbuilder
hs-libraries:         HSstringbuilder-0.5.1-9uHek5neZV4GQIWVfQI3Ym
depends:              base-4.18.2.1
haddock-interfaces:
    /usr/share/doc/haskell-stringbuilder/html/stringbuilder.haddock

haddock-html:         /usr/share/doc/haskell-stringbuilder/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
